Documentation
¶
Index ¶
- type Node
- type RelationshipEdge
- type RelationshipLine
- func (r *RelationshipLine) Attributes() (attrs []encoding.Attribute)
- func (r RelationshipLine) From() graph.Node
- func (r RelationshipLine) ID() int64
- func (r RelationshipLine) ReversedLine() graph.Line
- func (r *RelationshipLine) String() string
- func (r RelationshipLine) To() graph.Node
- func (r RelationshipLine) Weight() float64
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Node ¶
Node is a representation of a neo4j driver Node
func (*Node) Attributes ¶
type RelationshipEdge ¶
type RelationshipEdge struct {
Id int64
Start Node
End Node
Types []string
Properties map[string]any
// contains filtered or unexported fields
}
RelationshipEdge is a representation of a neo4j driver RelationshipEdge
var ( EmptyRelationshipEdge RelationshipEdge = RelationshipEdge{} EmptyRelationshipEdges []RelationshipEdge = []RelationshipEdge{} )
func NewRelationshipEdge ¶
func (*RelationshipEdge) Attributes ¶
func (r *RelationshipEdge) Attributes() (attrs []encoding.Attribute)
func (RelationshipEdge) From ¶
func (r RelationshipEdge) From() graph.Node
From allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Edge
func (RelationshipEdge) ReversedEdge ¶
func (r RelationshipEdge) ReversedEdge() graph.Edge
ReveresedEdge allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Edge
func (*RelationshipEdge) String ¶
func (r *RelationshipEdge) String() string
String prints all types of a Relationship in neo4j format
func (RelationshipEdge) To ¶
func (r RelationshipEdge) To() graph.Node
To allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Edge
func (RelationshipEdge) Weight ¶
func (r RelationshipEdge) Weight() float64
type RelationshipLine ¶
type RelationshipLine struct {
Id int64
Start Node
End Node
Types []string
Properties map[string]any
// contains filtered or unexported fields
}
var ( EmptyRelationshipLine RelationshipLine = RelationshipLine{} EmptyRelationshipLines []RelationshipLine = []RelationshipLine{} )
func NewRelationshipLine ¶
func (*RelationshipLine) Attributes ¶
func (r *RelationshipLine) Attributes() (attrs []encoding.Attribute)
func (RelationshipLine) From ¶
func (r RelationshipLine) From() graph.Node
From allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Line
func (RelationshipLine) ID ¶
func (r RelationshipLine) ID() int64
ID allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Line
func (RelationshipLine) ReversedLine ¶
func (r RelationshipLine) ReversedLine() graph.Line
ReversedLine allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Line
func (*RelationshipLine) String ¶
func (r *RelationshipLine) String() string
String prints all types of a Relationship in neo4j format
func (RelationshipLine) To ¶
func (r RelationshipLine) To() graph.Node
To allows a neo4j Relationship to satisfy the interface requirements of a gonum graph.Line
func (RelationshipLine) Weight ¶
func (r RelationshipLine) Weight() float64